
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Figure: Effect of Extended Provider Training on Patient Satisfaction
	
-------------------------------------------------------------------------------------------------------------------------------------*/

preserve

local reps= 500

// percentiles of predicted pos
_pctile pred_mal_pos, p(2.5 97.5)
local bottom=r(r1)
local top=r(r2)
_pctile pred_mal_pos, p(25 50 75)
	local p25= r(r1)
	local p50= r(r2)
	local p75= r(r3)

	egen grouper= group(infotreat patient_info)
	g info_control= infotreat==0
	
la var Asat_index_H "Overall Index" 
la var Asat_index_tests_H "Testing Sub-Index" 
la var Asat_index_meds_H "Medications Sub-Index"

// make local linear graphs and trim tails
local varlist "Asat_index_H Asat_index_tests_H Asat_index_meds_H" 

des `varlist' 

mat xgrid= J(51,1,.)

local interval= (`top' - `bottom')/50
	local qq=1
	forval i=`bottom'(`interval')`top' {
		mat xgrid[`qq',1]= `i'
		local ++qq
		}
		
svmat xgrid

// make local linear graphs and trim tails
foreach out of local varlist {
	di "`out'"

	lpoly `out' pred_mal_pos if infotreat==1, deg(1) gen(DIx_`out' DIy_`out') at(xgrid) nodraw
		mkmat DIy_`out' if xgrid!=., mat(q)
		mat RDI`out'= q
		
	lpoly `out' pred_mal_pos if infotreat==0, deg(1) gen(noDIx_`out' noDIy_`out') at(xgrid) nodraw
		mkmat noDIy_`out' if xgrid!=., mat(q)
		mat RnoDI`out'= q		
				
}

* REPLICATIONS
local k=1
	while `k'<=`reps' {
		
	drop _all
	use "$data_final/_bootstrap/infopaper_bs_cluCSCOM_`k'"

	rename RXtreat_sev_simple_mal RXtreat_sev_simp_mal
	g RXtreat_sev_simp_mal_RDT=RXtreat_sev_simp_mal if reported_RDT==1
	g RXtreat_sev_simp_mal_noRDT=RXtreat_sev_simp_mal if reported_RDT==0 //(reported_Malaria_test==0 | GE_FS_test_only==1 | mal_notspec_only==1)
			
	svmat xgrid

	// make local linear graphs and trim tails
		foreach out of local varlist {
		lpoly `out' pred_mal_pos if infotreat==1, deg(1) gen(DIy_`out') at(xgrid) nodraw
			mkmat DIy_`out' if xgrid!=., mat(q)
			mat RDI`out'= RDI`out',q
		lpoly `out' pred_mal_pos if infotreat==0, deg(1) gen(noDIy_`out') at(xgrid) nodraw
			mkmat noDIy_`out' if xgrid!=., mat(q)
			mat RnoDI`out'= RnoDI`out',q	
			}
	di `k'
	local ++k
}

* NOW CALCULATE CONFIDENCE INTERVALS
foreach out of local varlist {
	foreach let in DI noDI {
		mat ul= R`let'`out'[.,2...]'
		mat ll= ul
		mat pe= ul
			drop _all
			svmat ul
			svmat ll
			svmat pe
			collapse (p5) ll* (p95) ul* (sd) pe*
				mkmat ll1-ll51, mat(ll2)
				mkmat ul1-ul51, mat(ul2)
				mkmat pe1-pe51, mat(pe2)
					mat ul2= ul2'
					mat ll2= ll2'
					mat pe2= pe2'
					mat useme= R`let'`out'[1..51,1]
	 mat F`let'`out'= xgrid,useme,ul2,ll2,pe2 
	}
	
	drop _all 
		
	if "`out'"=="Asat_index_H" local tit_`out' "A. Aggregated Index"
	if "`out'"=="Asat_index_tests_H" local tit_`out' "B. Testing Sub-Index"
	if "`out'"=="Asat_index_meds_H" local tit_`out' "C. Medication Sub-Index"
		foreach let in DI noDI {
			svmat F`let'`out'
			g ul`let'= F`let'`out'2 + 1.645*F`let'`out'5
			g ll`let'= F`let'`out'2 - 1.645*F`let'`out'5			
			}
	* this version bootstraps the SEs	
	twoway (line  FnoDI`out'2  FDI`out'2 FDI`out'1, lcol( gs10 black ) lpat(solid solid) lwid(medthick medthick)) ///
	       (rarea ulnoDI llnoDI FDI`out'1, fcolor(gs10%40) lcol(gs10%4)) /// 
		   (rarea ulDI llDI FDI`out'1, fcolor(black%30) lcol(black%4)), ///
			graphregion(color(white)) legend(order(1 2) label(1 "Basic Provider Training") label(2 "Extended Provider Training") size(medium) row(1) region(col(white))) ///
			ytit("Satisfaction Index", size(medlarge)) ylab(-.4(.2).4) xtit("Predicted Malaria Risk", size(medlarge)) ///
			tit("`tit_`out''", size(large)) name(`out', replace) /// 
			xline(`p25', lcol(gs5) lpat(dash)) xline(`p50', lcol(gs5) lpat(dash)) xline(`p75', lcol(gs5) lpat(dash))
				
}
	
grc1leg Asat_index_H Asat_index_tests_H Asat_index_meds_H, row(1) graphregion(color(white))	name(final, replace)
gr dis final, xsize(10) ysize(4)	

* Output
graph export "$graphs/lpoly_satisfactionXpredpos_bootstrap.pdf", as(pdf) replace
	
restore
