
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Figure: Effect of Extended Provider Training on Testing at the Clinic
	
-------------------------------------------------------------------------------------------------------------------------------------*/

cap prog drop makevar
  prog define makevar
			
	g num_tests= reported_RDT + reported_GE_FS + reported_Malaria_testnotspec

	g RDT_only= reported_RDT==1 & num_tests==1 if !missing(num_tests)
	g double_test= inlist(num_tests,2,3) if !missing(num_tests)
	g GE_only= reported_GE_FS==1 & num_tests==1 if !missing(num_tests) 
	g Mal_NotSpec_only= num_tests>0 & (RDT_only + double_test + GE_only)==0 if !missing(num_tests)

	la var RDT_only "RDT Only"
	la var double_test "Multiple Tests"
	la var GE_only "Microscopy Only"
	la var Mal_NotSpec_only "Type Unknown Only"
	la var reported_Malaria_test "Any Malaria Test"

	la define infotreat 0 "Basic Training" 1 "Extended Training"
	label values infotreat infotreat	
end

makevar 

* Panel A
qui sum RDT_only
	local samp=r(N)
gr bar RDT_only  GE_only double_test Mal_NotSpec_only, stack over(infotreat) ///
	legend( label(4 "Type Unknown Only") label(1 "RDT Only") label(2 "Micro Only") label(3 "Multiple Tests") region(col(white))) ///
	graphregion(color(white)) bar(1, color(gs5)) bar(2, color(gs8)) bar(3, color(gs11)) bar(4, color(gs14)) ///
	ylabel(0(0.2)1) tit("A. All", size(medium))  ytit("Percent", size(medlarge)) name(PA, replace) note(N=`samp'.)
* Panel B
qui sum RDT_only if RDTresult_NEG==1
	local samp=r(N)
gr bar RDT_only  GE_only double_test Mal_NotSpec_only if RDTresult_NEG==1, stack over(infotreat) ///
	legend( label(4 "Type Unknown Only") label(1 "RDT Only") label(2 "Micro Only") label(3 "Multiple Tests") region(col(white))) ///
	graphregion(color(white)) bar(1, color(gs5)) bar(2, color(gs8)) bar(3, color(gs11)) bar(4, color(gs14)) ///
	note(Home survey sub-sample wiht negative at-home RDT. N=`samp'.) ///
	ylabel(0(0.2)1) tit("B. Negative RDT at Home Survey", size(medium))  ytit("Percent", size(medlarge)) name(PB, replace) 
* Panel C
qui sum RDT_only if RDTresult_POS==1
	local samp=r(N) 
gr bar RDT_only  GE_only double_test Mal_NotSpec_only if RDTresult_POS==1, stack over(infotreat) ///
	legend(label(4 "Type Unknown Only") label(1 "RDT Only") label(2 "Micro Only") label(3 "Multiple Tests") region(col(white))) ///
	graphregion(color(white)) bar(1, color(gs5)) bar(2, color(gs8)) bar(3, color(gs11)) bar(4, color(gs14)) /// 
	note(Home survey sub-sample with positive at-home RDT. N=`samp'.) ///
	ylabel(0(0.2)1) tit("C. Positive RDT at Home Survey", size(medium))  ytit("Percent", size(medlarge)) name(PC, replace) 

grc1leg PA PB PC, row(1) graphregion(color(white)) name(final, replace)
gr dis final, xsize(10) ysize(4)

* Output
gr export "$graphs/bar_doc_testing.pdf", replace
