
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Figure: Malaria Incident, Antimalarial Prescriptions, and Match Between Underlying Illness and Treatment
	
-------------------------------------------------------------------------------------------------------------------------------------*/

keep if RDTresult_POS!=.
keep if infotreat==0

	la var match_treat_RDT "Purchased"	
	la var RXmatch_treat_RDT "Purchased"
	
foreach lead in match_treat_RDT RXmatch_treat_RDT {
	g `lead'_pos= `lead'*RDTresult_POS if RDTresult_POS==1
	g `lead'_neg= `lead'*RDTresult_NEG if RDTresult_NEG==1 
}

g testtype= reported_RDT + 2*reported_GE_FS
	replace testtype=. if reported_Malaria_test==1 & testtype==0
	replace testtype=2 if testtype==3
	la define testtype 0 "Not tested" 1 "RDT Only" 2 "Microscopy"
	la val testtype testtype

* Panel A	
gr bar RDTresult_POS RXtreat_sev_simple_mal, over(testtype, label(labsize(small))) yscale(range(0 1)) ylabel(0(0.2)1) ///
	legend(label(1 "Malaria Positive (Home Test)") label(2 "Antimalarial Prescribed") size(vsmall) pos(6) col(2) region(col(white))) /// 
	graphregion(color(white)) bar(1, color(gs5)) bar(2, color(gs8))  name(misallocation_a, replace) /// 
	title("A. Malaria Incidence and Antimalarial Prescriptions by In-Clinic Testing Status", size(small))  bargap(30) ytit("Share of Patients", size(small)) 
* Panel B	
gr bar RXmatch_treat_RDT RXmatch_treat_RDT_neg RXmatch_treat_RDT_pos, over(testtype, label(labsize(small))) yscale(range(0 1))  ylabel(0(0.2)1)  /// 
	legend(label(1 "All Patients") label(2 "Malaria Negative Patients") label(3 "Malaria Positive Patients")  size(vsmall) pos(6) col(3) region(col(white))) /// 	
	graphregion(color(white)) bar(3, color(gs11)) bar(2, color(gs8)) bar(1, color(gs5)) name(misallocation_b, replace) ///
	title("B. Match between Malaria Test Result and Prescribed Treatment", size(small)) bargap(10) ytit("Share of Patients", size(small)) 

gr combine misallocation_a misallocation_b, xsize(10) ysize(10)	col(1) graphregion(color(white)) 

* Output	
graph export "$graphs/bar_misallocation.pdf", replace 

* Data to add below the figure
sum RDTresult_POS if infotreat==0
local positive_rdt=r(mean)*100
di `positive_rdt'

sum RXtreat_sev_simple_mal if infotreat==0
local rx=r(mean)*100
di `rx'

