
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Figure: Effect of Extended Provider Training on Patient Satisfaction
	
-------------------------------------------------------------------------------------------------------------------------------------*/

la define infotreat 0 "Basic Training" 1 "Extended Training"
la val infotreat infotreat
	
* ------------------------------------------------------------------------------
* SATISFACTION INDICES
* ------------------------------------------------------------------------------
/*
cap prog drop indexmake
prog define indexmake 

ren doctorsfinancialsituation_H dfinsit_H
ren doctorsmeddontneed_H dmednot_H

local posframe "explaintests_H treatbasedresults_H explaindiagnosis_H doctorspatients_H doctorscosts_H doctorslisten_H"			   
local negframe "addmedicaltesting_H fewermedicaltests_H diffaddmed_H fewermed_H dfinsit_H dmednot_H"			   
	
foreach var in `posframe' `negframe'  {
	replace `var'=. if `var'<-2
	g A`var'= `var'>0 if !missing(`var')
	g NA`var'= -1*A`var'
	
		local mylab: var label `var'
			if "`mylab'"=="" local mylab "`var'"
		la var A`var' "Agrees: `mylab'"
		la var NA`var' "Negative of Agree: `mylab'"
}

	egen grouper= group(infotreat patient_info)
	g info_control= (infotreat==0 & patient_info==0)
	
local sat_index_H "explaindiagnosis_H explaintests_H treatbasedresults_H addmedicaltesting_H fewermedicaltests_H diffaddmed_H fewermed_H"  // main index
local sat_index_tests_H "explaintests_H treatbasedresults_H  addmedicaltesting_H fewermedicaltests_H "                                          // testing 
local sat_index_meds_H "diffaddmed_H fewermed_H" // meds

foreach stem in sat_index_H sat_index_tests_H sat_index_meds_H {

	local A`stem'= ""
	
	foreach var in ``stem'' {
		di "`var'"
		if strpos("`posframe'","`var'")>0 { 
			local A`stem'= "`A`stem'' A`var'"
		}
		if strpos("`negframe'","`var'")>0 {
			local A`stem'= "`A`stem'' NA`var'"
		}
	}
	makeindex `A`stem'', indexname(A`stem') groupby(grouper) omit(info_control)

}

la var Asat_index_H "Satisfaction: Overall Index (Agree Dummies Only)"
la var Asat_index_tests_H "Satisfaction: Tests (Agree Dummies Only)"
la var Asat_index_meds_H "Satisfaction: Medications (Agree Dummies Only)"

ren dfinsit_H doctorsfinancialsituation_H
ren dmednot_H doctorsmeddontneed_H

drop grouper info_control

end
	 
indexmake
*/	
	
la var Asat_index_H "Overall Index" 
la var Asat_index_tests_H "Testing Sub-Index" 
la var Asat_index_meds_H "Medications Sub-Index"

foreach var in Asat_index_H Asat_index_tests_H Asat_index_meds_H {
	local labz : variable label `var'
	ksmirnov `var', by(infotreat)
		local myp= r(p)
		local myp= trim("`: display %10.3f `myp''")
	distplot `var', over(infotreat) legend(region(col(white))) graphregion(color(white)) lcol(black gs5) lpat(dash solid) note("KS p-value for equality of distributions is p=`myp'.") name(`var', replace) tit("`labz'", size(medlarge)) xtit("") ytit("Cumulative probability")
	}
	
grc1leg Asat_index_H Asat_index_tests_H Asat_index_meds_H, row(1)  graphregion(color(white)) name(final, replace)
gr dis final, xsize(10) ysize(4)

* Output
gr export "$graphs/cdfs_patient_satisfaction.pdf", replace		 
	
