/*------------------------------------------------------------------------------
********************************************************************************
* Lopez, Sautmann, Schaner
********************************************************************************

** Programs to make tables for analysis.

------------------------------------------------------------------------------*/

cap prog drop boot_ols
prog define boot_ols, eclass

syntax anything [if] [in] , REPName(string) REPPath(string) NUMreps(integer) [DOFirst(string)] [MAindata(string)] [DONEXT(string)]
	marksample touse
	preserve
set more off
* FIRST RUN THE MAIN REGRESSION
qui `anything' `if' 
	tempfile starthere
	save `starthere'
	mat beta= e(b) /* get initial parameter vector */
	local cols= colsof(beta) 
	local obs=e(N)
	local dvar=e(depvar)
	local rname: rowfullnames e(V)
	local cname: colfullnames e(V)
		mat reps=J(`numreps',`cols',.)
* NEXT DO A WHOLE BUNCH OF REPLICATIONS
local i=1
	while `i'<=`numreps' {
qui {
	drop _all
		use "`reppath'/`repname'`i'"
		`dofirst'
		`donext'
		`anything' `if' [`wt']
		mat reps[`i',1]=e(b) 
}
		noisily { 
			if floor(`i'/50)==`i'/50 di "`i'"
				else di "." _cont
				}
		local ++i
		} /* closes loop where we do command over and over */
* NEXT CALCULATE STANDARD ERRORS
drop _all
	svmat reps
	mat accum var= * [iw=1/`numreps'], dev nocons 
	mat colnames var= `cname'
	mat rownames var= `rname'
		* DISPLAY RESULTS
		*di _n in gr  "Bootstrapped Results"
drop _all
use `starthere'
qui `anything' `if' 
      * ereturn post beta var, esample(`touse') obs(`obs') depname(`dvar') 
	  ereturn repost b=beta V=var 
	   ereturn display
restore	   
end
	

cap prog drop makeindex 
	prog define makeindex 
		syntax varlist(numeric min=1) [if], INDEXName(string) GROUPBY(string) OMIT(string) [ROTATE(string)]
	
	qui {
		
	tempvar isok
		// mark sample w at least one non-mising obs
		egen `isok'= rowmean(`varlist') `if'
		replace `isok'= !missing(`isok') `if'
		
		g `indexname'=0 if `isok'==1 
		
	foreach var in `varlist' {
		// recode to mean w/in group if isok>0	
		tempvar M`var'
		tempvar W`var'
		tempvar S`var'
		
			g `W`var''=`var'
			if strpos("`rotate'","`var'")>0 { 
				replace `W`var''= -1*`W`var''
			}
		egen `M`var''= mean(`var'), by(`groupby')
		replace `W`var''= `M`var'' if missing(`var') & `isok'==1
		
		// create a standardize version of the imputed variable
		qui sum `W`var'' if `omit'==1 & `isok'==1
			g `S`var''= (`W`var''-r(mean))/r(sd)
			
		// add to index
		replace `indexname'= `indexname'+`S`var''
	}
	
	local denom: word count `varlist' 		
		replace `indexname'= `indexname'/`denom'
	}
	
	end

cap prog drop docpat_doc 
prog define docpat_doc
	est clear
syntax varlist [if], TEXWID(string) [Table(string)] [EXtra(varlist)]  [TYPE(string)] [FOOTNOTE(string)] [PREHEAD1(string)] /// 
	                 [PREHEAD2(string)] [TITLE(string)] [LABel(string)] WIDC(string) [FOOTNOTE2(string)]  /// 
					 [EXTRAHEAD(string)] [EXTRAVARHead(string)] CLUVar(string) [PARTIAL(string)] 
	
qui {


local q= 2
	local colcount= wordcount("`varlist'")+1
	local seclast= `q'-1	
	
// locals to assist in making the table
local ester=1
forval i=1/`q' {
	local eststr`i' ""	
	local Neststr`i' ""	
	}
	
// label covariates
la var infotreat "Extended Training"
local counter=1	
	
	local varhead ""
	local paren`counter' ""
	foreach out in `varlist'  {
	
	// GET LABELS HERE
	local labelq : variable label `out'
		local varhead "`varhead'& `labelq'" //this is the label for columns		
			
		pdslasso `out' infotreat patient_info (`extra') `if', partial(`partial') clu(`cluvar') loptions(seed(1234))
		
		qui sum `out' if e(sample) & infotreat==0 & patient_info==0
			local control: display %10.2f `r(mean)'
				estadd scalar control=`control'
			
			est store E`ester'
			
		reg `out' infotreat patient_info `partial' `if', clu(`cluvar') 
			estadd scalar control=`control'
			est store NE`ester'
			
				local eststr`counter' "`eststr`counter'' E`ester'"
				local Neststr`counter' "`Neststr`counter'' NE`ester'"
				local paren`counter' "`paren`counter'' & (`ester')" // column numbers
				local ++ester	
		
		}
		local ++counter	
		cap drop kludge
		} //end qui loop
* FIRST PANEL		
esttab `eststr1' using "`table'.tex", keep( infotreat patient_info) label  noabbrev `type' replace nogaps nomtit nonum collabels(none) eqlabels(none) ///
		cell( b(fmt(a3) star ) se(par fmt(a3) )) ///
		stats(space control N, fmt(0 %10.2f a0) labels(" " "Mean (Basic Training, No Pat. Info.)" "N")) ///
		nonote  star(* 0.10 ** 0.05 *** 0.01) `extrac1' ///
		b(a2) se(a2) noline subs("\beta\_" "\beta_") /// 
		prehead("\begin{table}[h!] \begin{adjustbox}{max width=`texwid'\textwidth} \begin{threeparttable} \caption{`title'} \label{`label'} {\begin{tabular}{l*{`colcount'}{C{`widc'}}} \toprule `paren1' `extrahead'  `varhead' `extravarhead' \\ \midrule ")  /// 
		postfoot(\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small \item `footnote' \end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) 

esttab `Neststr1' using "`table'_nocont.tex", keep( infotreat patient_info) label  noabbrev `type' replace nogaps nomtit nonum collabels(none) eqlabels(none) ///
		cell( b(fmt(a3) star ) se(par fmt(a3) )) ///
		stats(space control N, fmt(0 %10.2f a0) labels(" " "Mean (Basic Training, No Pat. Info.)" "N")) ///
		nonote  star(* 0.10 ** 0.05 *** 0.01) `extrac1' ///
		b(a2) se(a2) noline subs("\beta\_" "\beta_") /// 
		prehead("\begin{table}[h!] \begin{adjustbox}{max width=`texwid'\textwidth} \begin{threeparttable} \caption{`title' -- No Additional Controls} \label{`label'_nocont} {\begin{tabular}{l*{`colcount'}{C{`widc'}}} \toprule `paren1' `extrahead'  `varhead' `extravarhead' \\ \midrule ")  /// 
		postfoot(\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small \item `footnote2' \end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) 
		
end		

 

cap prog drop docpat_doc_inter
prog define docpat_doc_inter
	est clear
syntax varlist [if], TEXWID(string) [Table(string)] [EXtra(varlist)]  [TYPE(string)] [FOOTnote(string)] [PREHEAD1(string)] /// 
	                 [PREHEAD2(string)] [TITLE(string)] [LABel(string)] WIDC(string) [EXTRAC1(string)] [EXTRAC2(string)] /// 
					 [EXTRAHEAD(string)] [EXTRAVARHead(string)] CLUVar(string)  PARTIAL(string)
	
qui {


local q= 2
	local colcount= wordcount("`varlist'")+1
	local seclast= `q'-1	
	
// locals to assist in making the table
local ester=1
forval i=1/`q' {
	local eststr`i' ""	
	}
	
// label covariates
la var infotreat "Extended Training"
la var patient_info "Patient Information"
la var infotreatXPI "Extended Training $\times$ Patient Information"

local counter=1	
	
	local varhead ""
	local paren`counter' ""
	foreach out in `varlist'  {
	
	// GET LABELS HERE
	local labelq : variable label `out'
		local varhead "`varhead'& `labelq'" //this is the label for columns		
		
	pdslasso `out' infotreat patient_info infotreatXPI (`extra') `if', partial(`partial') loptions(seed(1234)) clu(`cluvar')	
			test infotreat + infotreatXPI=0 
				local p_info= r(p)
				local star ""
					if `p_info'<=.01 local star "\sym{***}"
					if `p_info'>.01 & `p_info'<=.05 local star "\sym{**}"	
					if `p_info'>.05 & `p_info'<=.1 local star "\sym{*}"	
					local d_info_risk = trim("`: display %10.3f `p_info''")
					local combo "`d_info_risk'`star'"
				estadd local pval `combo'
			
		qui sum `out' if e(sample) & infotreat==0 & patient_info==0
		local control_DI: display %10.2f `r(mean)'
		estadd scalar control_DI=`control_DI'
				
			est store E`ester'
				local eststr`counter' "`eststr`counter'' E`ester'"
				local paren`counter' "`paren`counter'' & (`ester')" // column numbers
				local ++ester	
		}
		local ++counter	
		} //end qui loop
* FIRST PANEL		
esttab `eststr1' using "`table'", keep(infotreat patient_info infotreatXPI) replace label nogaps nomtit nonum collabels(none) eqlabels(none) ///
		cell(b(fmt(a3) star ) se(par fmt(a3) )) ///
		stats(space pval space control_DI N, fmt(a0 a2 a0 %10.2f a0) labels(" " "P-Value: ET + ET $\times$ PI=0"  " " "Mean (Basic Training, No Pat. Info.)" "N")) ///
		nonote  star(* 0.10 ** 0.05 *** 0.01) `extrac1' ///
		b(a2) se(a2) noline subs("\beta\_" "\beta_") /// 
		prehead("\begin{table}[h!] \begin{adjustbox}{max width=`texwid'\textwidth} \begin{threeparttable} \caption{`title'} \label{`label'} {\begin{tabular}{l*{`colcount'}{C{`widc'}}} \toprule `paren1' `extrahead' \\ `varhead' `extravarhead' \\ \midrule ")  /// 
		postfoot(\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small \item `footnote' \end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) 
end		



cap prog drop docpat_doc_pat
prog define docpat_doc_pat
	est clear
syntax varlist [if], TEXWID(string) [Table(string)] [EXtra(varlist)]  [TYPE(string)] [FOOTnote(string)] [PREHEAD1(string)] /// 
	                 [PREHEAD2(string)] [TITLE(string)] [LABel(string)] WIDC(string) [EXTRAC1(string)] [EXTRAC2(string)] /// 
					 [EXTRAHEAD(string)] [EXTRAVARHead(string)] CLUVar(string) PARTIAL(string)
	
qui {


local q= 2
	local colcount= wordcount("`varlist'")+1
	local seclast= `q'-1	
	
// locals to assist in making the table
local ester=1
forval i=1/`q' {
	local eststr`i' ""	
	}
	
// label covariates
la var infotreat "Extended Training"
la var patient_info "Patient Information"

local counter=1	
	
	local varhead ""
	local paren`counter' ""
	foreach out in `varlist'  {
	
	// GET LABELS HERE
	local labelq : variable label `out'
		local varhead "`varhead'& `labelq'" //this is the label for columns		
		
	pdslasso `out' infotreat patient_info  (`extra') `if', partial(`partial') clu(`cluvar')	loptions(seed(1234))
			
		qui sum `out' if e(sample) & infotreat==0 & patient_info==0
		local control_DI: display %10.2f `r(mean)'
		estadd scalar control_DI=`control_DI'
				
			est store E`ester'
				local eststr`counter' "`eststr`counter'' E`ester'"
				local paren`counter' "`paren`counter'' & (`ester')" // column numbers
				local ++ester	
		}
		local ++counter	
		} //end qui loop
* FIRST PANEL		
esttab `eststr1' using "`table'", keep(infotreat patient_info) replace label nogaps nomtit nonum collabels(none) eqlabels(none) ///
		cell(b(fmt(a3) star ) se(par fmt(a3) ) ) ///
		stats(space control_DI N, fmt(0 %8.2f a0) labels(" "   "Mean (Basic Training, No Pat Info)" "N")) ///
		nonote  star(* 0.10 ** 0.05 *** 0.01) `extrac1' ///
		b(a2) se(a2) noline subs("\beta\_" "\beta_") /// 
		prehead("\begin{table}[h!] \begin{adjustbox}{max width=`texwid'\textwidth} \begin{threeparttable} \caption{`title'} \label{`label'} {\begin{tabular}{l*{`colcount'}{C{`widc'}}} \toprule `paren1' `extrahead' `varhead' `extravarhead' \\ \midrule ")  /// 
		postfoot(\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small \item `footnote' \end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) 
end		


cap prog drop docpat_doc_erac
prog define docpat_doc_erac
	est clear
syntax varlist [if], [TEXWID(string)] [Table(string)] [EXtra(varlist)]  [TYPE(string)] [FOOTnote(string)] [PREHEAD1(string)]  /// 
	                 [PREHEAD2(string)] [TITLE(string)] [LABel(string)] [WIDC(string)] PREPROG(string) PVALLAB(string) CATLAB(string) /// 
					 [EXTRAHEAD(string)] [EXTRAVARHead(string)] [CLUVar(string)] [PARTIAL(string)] [ERACORDER(string)] /// 
					 [BOOTER(string)] [PPBOOT(string)] [BOOTPATH(string)] [BOOTNAME(string)] [BOOTREP(string)]

	qui {

tokenize `eracorder'

local q= 2
	local colcount= wordcount("`varlist'")+1
	local seclast= `q'-1	
	
// locals to assist in making the table
local ester=1
forval i=1/`q' {
	local eststr`i' ""	
	}

local counter=1	
local counter2=1	
	
	local varhead ""
	local paren`counter' ""

	foreach out in `varlist'  {
		
	local bootstat: word `counter2' of `booter'
		
	// GET LABELS HERE
	local labelq : variable label `out'
		local varhead "`varhead'& `labelq'" //this is the label for columns		
		
		`preprog' ``counter2''
	
		 pdslasso `out' infotreat erac patient_info (risk `extra') `if', partial(risk `partial') clu(`cluvar') loptions(seed(1234))

		 if "`bootstat'"=="1" {
					local xvar= "infotreat erac patient_info `e(xpartial)' `e(xselected)'"
					noi boot_ols reg `out' `xvar' `if', numreps(`bootrep') reppath("`bootpath'") repname(`bootname') dofirst(`ppboot') donext(`preprog' ``counter2'')
		 }
				test infotreat + erac= 0 
				local p_info= r(p)
				local star ""
					if `p_info'<=.01 local star "\sym{***}"
					if `p_info'>.01 & `p_info'<=.05 local star "\sym{**}"	
					if `p_info'>.05 & `p_info'<=.1 local star "\sym{*}"	
					local d_info_risk = trim("`: display %10.3f `p_info''")
					local combo "`d_info_risk'`star'"
				estadd local d_info_inforisk `combo'
	
	
	 sum `out' if e(sample) & infotreat==0 & patient_info==0
			local control_DI: display %10.2f `r(mean)'
				estadd scalar control_DI=`control_DI'
				
				local typez: var label risk``counter2''
						estadd local tt "`typez'"				
						
			est store E`ester'
				local eststr`counter' "`eststr`counter'' E`ester'"
				local paren`counter' "`paren`counter'' & (`ester')" // column numbers
				local ++ester	
		
		local ++counter2
		}
		} //end qui loop
		local ++counter
* FIRST PANEL		

esttab `eststr1' using "`table'", keep(infotreat erac risk) label  noabbrev `type' replace nogaps nomtit nonum collabels(none) eqlabels(none) ///
		cell(b(fmt(a3) star ) se(par fmt(a3) ) ) ///
		stats( space d_info_inforisk space tt space control_DI N, fmt(0 a2 0 0 0 %10.2f a0) labels( " "  "`pvallab'" " " "`catlab'" " " "Mean (Basic Training, No Pat. Info.)" "N")) ///
		nonote  star(* 0.10 ** 0.05 *** 0.01) `extrac1' ///
		b(a2) se(a2) noline subs("\beta\_" "\beta_") /// 
		prehead("\begin{table}[h!] \begin{adjustbox}{max width=`texwid'\textwidth} \begin{threeparttable} \caption{`title'} \label{`label'} {\begin{tabular}{l*{`colcount'}{C{`widc'}}} \toprule `paren1' `extrahead'  `varhead' `extravarhead' \\ \midrule ")  /// 
		postfoot(\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small \item `footnote' \end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) 
end		
