* *****************************************************
* PROGRAM: LSS_info_make_bootstrap_repsets
* PROGRAMMER: Simone Schaner
* DATE CREATED: 29 March 2019
* MODIFIED 11/2023
* THIS FILE MAKES 1000 BOOTSTRAP REPLICATION DATASETS
* TO SPEED UP BOOTSTRAP CALCS IN MAIN PAPER
* PROCESS :: 
*		(1) sample 58 clinics w/ replacement
*		(2) apply sample exclusion criteria
*		(3) calculated predicted malaria positivity and
*			associated variables
*		(4) save replicant dataset
* *****************************************************

set seed 34645
local reps= 1000
local i=1
local k=1
use "$data_final/LSS_info_DocPat_analysis_datasets_allcont.dta", clear
		drop *pred_mal_pos*
		drop above_med_pos below_med_pos 
			global predcont "symptomsscreening_1 symptomsscreening_2 symptomsscreening_3 symptomsscreening_4 symptomsscreening_5 symptomsscreening_6 symptomsscreening_7  daysillness99 agepatient under5 u5_age genderpatient pregnancy ethnic_bambara speak_french readwrite_fluent_french prischoolorless respondent" 
			global useme ""
				foreach var in $predcont {
					cap drop MSS`var'
					sum `var'
						if r(N)!=_N { 
							g MSS`var'= missing(`var')
							replace `var'=0 if MSS`var'==1
							global useme "$useme `var' MSS`var'"
						}
						else global useme "$useme `var'"
				}
		
while `i'<=`reps' {
		preserve	
			bsample 29, cluster(info_strata)
				keep if dropme==0
			probit RDTresult_POS  $useme ,  asis iter(1000)
				if e(converged)==1 {
					predict pred_mal_pos, p			
						qui sum pred_mal_pos, detail
							g above_med_pos= pred_mal_pos>=r(p50) if pred_mal_pos!=.
							g below_med_pos= above_med_pos==0 if above_med_pos!=. 	
							la var above_med_pos "High Malaria Prob."
						la var below_med_pos "Low Malaria Prob."
						save "$data_final/_bootstrap/infopaper_bs_cluCSCOM_`i'", replace
								local ++i
					}
		di `k'
		di `i'-1
		local ++k
		restore
		}
	
