
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Provider Beliefs in the Control Group: Health Worker Post-Intervention Survey
	
-------------------------------------------------------------------------------------------------------------------------------------*/

preserve

g mal_cscom= (malariaabove5 + malariaunder5)/100
	la var mal_cscom "Malaria Prevalence: CSCom Patients"
	la var prevalencemalaria "Malaria Prevalence: General Population"
	la var whichmedicines_antimalarial "\enspace Feels Pressure: Antimalarials"
	la var whichmedicines_painkiller "\enspace Feels Pressure: Pain Killers"
	la var whichmedicines_antibiotic "\enspace Feels Pressure: Antibiotics"
	la var whichmedicines_other "\enspace Feels Pressure: Other Medicines"
	la var pressuremedicines "Feels Pressure from Patients to Prescribe Unnecessary Medication"
	la var simplemalaria_rdtpos "Positive out of 100: Simple Malaria" 
	replace simplemalaria_rdtpos=simplemalaria_rdtpos*100
	la var severemalaria_rdtpos "Patients with Positive RDT out of 100 with Severe Malaria" 
	replace severemalaria_rdtpos=severemalaria_rdtpos*100
	la var notmalaria_rdtneg "Patients with Negative RDT out of 100 without Malaria" 
	replace notmalaria_rdtneg=notmalaria_rdtneg*100
	la var simplemalaria_gepos "Patients with Positive Microscopy Test out of 100 with Simple Malaria"
	replace simplemalaria_gepos=simplemalaria_gepos*100
	la var severemalaria_gepos "Patients with Positive Microscopy Test out of 100 with Severe Malaria" 
	replace severemalaria_gepos=severemalaria_gepos*100
	la var notmalaria_geneg "Patients with Positive Microscopy Test out of 100 without Malaria" 
	replace notmalaria_geneg=notmalaria_geneg*100	
		
		label var diag_GE_FM "Uses Microscopy to Diagnose Malaria"
		label var diag_rdt "Uses RDT to Diagnose Malaria"
		label var notadhere_negrdt "Would Treat Relative with Negative RDT"
		label var notadhere_negge "Would Treat Relative with Negative Microscopy Test"


local varlist "prevalencemalaria mal_cscom pressuremedicines whichmedicines_antimalarial  diag_rdt simplemalaria_rdtpos severemalaria_rdtpos  notadhere_negrdt diag_GE_FM  simplemalaria_gepos severemalaria_gepos  notadhere_negge"
local v0= wordcount("`varlist'")

local totrow= `v0'
matrix table_mean=J(`totrow',3,.)
	
local f=1
foreach var of local varlist{

local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &"
		
	*Average for treatment group
	sum `var' if infotreat==0  & trained==1
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_mean[`f',2] =`control_mean'
	matrix table_mean[`f',3] =`control_sd'
	matrix table_mean[`f',1] =r(N)
	
	*Increase the counter of the row 
	loc f = `f' + 1

}

drop _all
svmat table_mean
g t0=""
	forval i=1/`totrow' {
		di "`part`i''"
		replace t0= "`part`i''" if _n==`i'
	}
	
forval var=2/3 {
		tostring table_mean`var', format("%9.3f") replace force
			replace table_mean`var'="" if table_mean`var'=="."
			replace table_mean`var'="0"+table_mean`var' if substr(table_mean`var',1,1)=="."
		
	}	
			tostring table_mean1, format("%9.0f") replace force
	
forval i=1/2 {
		replace table_mean`i'= table_mean`i'+"&"
	}
			replace table_mean1="" if table_mean1=="."
			replace table_mean1="0"+table_mean1 if substr(table_mean1,1,1)=="."

		replace table_mean3= table_mean3+"\\" if table_mean3!=""
		replace table_mean3= table_mean3+"& \\" if table_mean3==""	
	
set obs `=_N+5'		
	g index= _n
	replace index=0 if _n==_N-1
		replace index=.5 if _n==_N-2
		replace index=4.5 if _n==_N-3
		replace index=8.5 if _n==_N-4

			replace t0= "\addlinespace \emph{Panel A. Malaria Prevalence and Pressure} &\\" if index==.5
			replace t0= "\addlinespace \emph{Panel B. Confidence in RDT} &\\" if index==4.5
			replace t0= "\addlinespace \emph{Panel C. Confidence in Microscopy Test} &\\" if index==8.5

		
	sort index	
	sort index
order t0 table_mean1-table_mean3
keep t0-table_mean3

* Set a proper linesize within the allowable range
set linesize 80

list, clean 	

#delimit ;
local fn "Notes: Results from post-intervention health worker survey. Sample limited to clinics that received the basic provider training. Malaria prevalence refers to prevalence estimated by the health worker. A health worker is coded as feeling pressure to prescribe if s/he answers yes to the question: Do you ever feel pressure from patients to prescribe certain medicines when you think they are not necessary? Providers answering yes were then asked to specify which medications. Antimalarial also includes quinine.";
local text0 "\begin{table}[h!] \begin{adjustbox}{max width=.85\textwidth} \begin{threeparttable} \caption{Provider Beliefs in the Control Group: Health Worker Post-Intervention Survey} \label{doc_control_group} { 
			\begin{tabular}{l*{4}{c}} \toprule & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)}  \\
			& \multicolumn{1}{c}{\shortstack{N}} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{SD} \\ \midrule";
local textlast "\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="`text0'" if _n==1
	replace t0="`textlast'" if _n==_N

* Output	
outfile t0-table_mean3 using "$tables/doc_control_group.tex", noquote replace wide		

restore

