
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Effect of Extended Provider Training on the Allocation of Malaria Treatment
	
-------------------------------------------------------------------------------------------------------------------------------------*/

cap prog drop makevar
	prog define makevar
		args myct
		
* match measures
g match_pred= pred_mal_pos*RXtreat_sev_simple_mal + (1-pred_mal_pos)*(1-RXtreat_sev_simple_mal)
g match_actual= RDTresult_POS*RXtreat_sev_simple_mal + RDTresult_NEG*(1-RXtreat_sev_simple_mal) if RDTresult_POS+RDTresult_NEG==1	
g match_pred_sub= match_pred if !missing(match_actual)	
		la var match_pred "Expected Match"
		la var match_pred_sub "Expected Match"
		la var match_actual "Actual Match"
		
		g erac1= infotreat*above_med_pos 
		g erac3= infotreat*RDTresult_POS
		g erac2= infotreat*pred_mal_pos
			la var erac1 "Extended Training $\times$ Above Median Malaria Risk"
			la var erac3 "Extended Training $\times$ RDT Positive"
			la var erac2 "Extended Training $\times$ Predicted Malaria Risk"
			la var pred_mal_pos "Predicted Malaria Risk"
			la var RDTresult_POS "RDT Positive"
			la var above_med_pos "Above Median Malaria Risk"
* gen subsamples			
		g RXtreat_sev_simple_mal_sub= RXtreat_sev_simple_mal if RDTresult_POS!=.
			la var RXtreat_sev_simple_mal_sub "Prescribed Antimalarial"
			la var RXtreat_sev_simple_mal "Prescribed Antimalarial"

		g RXtreat_severe_mal_sub= RXtreat_severe_mal if RDTresult_POS!=.
			la var RXtreat_severe_mal "Prescribed Severe Antimalarial"
			la var RXtreat_severe_mal_sub "Prescribed Severe Antimalarial"	
				
		g RXtreat_sev_simple_mal_home= RXtreat_sev_simple_mal if home==1
			la var RXtreat_sev_simple_mal_home "Prescribed Antimalarial"
		g RXtreat_severe_mal_home= RXtreat_severe_mal if home==1
			la var RXtreat_severe_mal_home "Prescribed Severe Antimalarial"
			
		g satisfaction_index_H_sub= satisfaction_index_H if RDTresult_POS!=.
			la var satisfaction_index_H_sub "Aggregate Index"
		
				ren above_med_pos risk1
				ren pred_mal_pos risk2		
				ren RDTresult_POS risk3
				
			g erac=.
			g risk=.
				la var risk "Malaria Risk Measure"
				la var erac "Extended Training $\times$ Malaria Risk"
				la var infotreat "Extended Training"
				 replace erac= erac`myct'
				 replace risk= risk`myct'
				 
					qui tab date_group, ge(Dgroup)	 
	 
				 
			end	
			
cap prog drop makevar2
	prog define makevar2
		args myct
		  replace erac= erac`myct'
		  replace risk= risk`myct'
	end
	
makevar 1
		
*All 
docpat_doc_erac RXtreat_sev_simple_mal RXtreat_sev_simple_mal RXtreat_sev_simple_mal_sub RXtreat_sev_simple_mal_sub RXtreat_sev_simple_mal_sub, preprog(makevar2) /// 
	cluvar($cluvar) widc(0.11\linewidth) eracorder(1 2 1 2 3) extra( $cont_strat $cont_lso $cont_date)  type(tex) texwid(1) ///
		table("$tables/doc_treat_allocn_inter.tex") footnote($footnote0_alt_pat_bs $footnote1) partial( $cont_strat $cont_date)  /// 
		prehead1($prehead1) title("Effect of Extended Provider Training on the Allocation of Malaria Treatment") lab(doc_treat_allocn_inter)  ///
	    prehead2($prehead2) pvallab("ET + ET $\times$ Risk = 0") catlab("Malaria Risk Indicator") /// 
		extrahead(\\ & \multicolumn{2}{c}{Full Sample} & \multicolumn{3}{c}{Has Valid Home-Based RDT} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-6})	/// 
		booter(1 1 1 1 0) bootpath("$data_final/_bootstrap") bootname(infopaper_bs_cluCSCOM_) ppboot(makevar 1) bootrep(500)	

		
