
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Effect of Extended Provider Training on Match Between Patient Prior and Prescription by Accuracy of Pre-Consultation Malaria Beliefs
	
-------------------------------------------------------------------------------------------------------------------------------------*/

cap prog drop makevar
  prog define makevar
	drop if dropme==1

		g RXtreat_sev_simple_mal_sub= RXtreat_sev_simple_mal if RDTresult_POS!=.
			la var RXtreat_sev_simple_mal_sub "Prescribed Antimalarial"
			la var RXtreat_sev_simple_mal "Prescribed Antimalarial"
			la var satisfaction_index_H "Aggregate Index"
		g RXtreat_sev_simple_mal_home= RXtreat_sev_simple_mal if home==1
			la var RXtreat_sev_simple_mal_home "Prescribed Antimalarial"

g got_wanted= thinks_malaria*RXtreat_sev_simple_mal + (1-thinks_malaria)*(1-RXtreat_sev_simple_mal)
g got_wanted_HR= got_wanted if !missing(RDTresult_NEG)
	la var got_wanted "Prescription Matches Malaria Prior"
	la var got_wanted_HR "Prescription Matches Malaria Prior"
	
			g erac=prior_match_pred*infotreat
			g risk=prior_match_pred
				la var risk "Match: Malaria Prior and Malaria Risk"
				la var erac "Extended Training $\times$ Prior-Risk Match"
				la var infotreat "Extended Training"
				
	g prior_match= (thinks_malaria*RDTresult_POS + (1-thinks_malaria)*RDTresult_NEG)
		g prior_match_info= infotreat*prior_match
		g prior_match_info_pred= infotreat*prior_match_pred
		
	g mal_test_info= reported_Malaria_test*infotreat
		la var prior_match "Malaria Prior Matches Home RDT"
		la var prior_match_pred "Expected Mismatch - Malaria Status and Prior"
		la var prior_match_info "Extended Training $\times$ Malaria Prior Match"
		la var prior_match_info_pred "Extended Training $\times$ Expected Malaria Prior Match"

g risk1= prior_match_pred 
g risk2= prior_match 
	la var risk1 "Expected Prior Match"
	la var risk2 "Actual Prior Match (Home RDT)"
g erac1= risk1*infotreat
g erac2= risk2*infotreat

g infotreatXPI= infotreat*patient_info
la var patient_info "Patient Information"
		
end


makevar

cap prog drop makevar2
	prog define makevar2
		args myct
		  replace erac= erac`myct'
		  replace risk= risk`myct'
	end
		
#delimit ;
local indexfn "Outcome is equal to one for patients who, pre-consultation, believe they have malaria and are prescribed an antimalarial \emph{or} for patients who believe they do not have malaria and are not prescribed an antimalarial.";
#delimit cr
 
* W/ controls
docpat_doc_erac got_wanted got_wanted_HR got_wanted_HR, preprog(makevar2) /// 
	cluvar($cluvar) widc(0.15\linewidth) eracorder(1 1 2) extra($cont_strat $cont_lso $cont_date) /// 
		partial($cont_strat $cont_date) type(tex) texwid(1) ///
		table("$tables/got_wanted_priorhet_match.tex") footnote($footnote0_alt_pat_bs `indexfn' $footnote1) lab(got_wanted_priorhet_match) /// 
		prehead1($prehead1) title("Effect of Extended Provider Training on Match Between Patient Prior and Prescription by Accuracy of Pre-Consultation Malaria Beliefs") ///
	    prehead2($prehead2) pvallab("P-value: ET + ET $\times$ Prior Match = 0") catlab("Prior Match Measure") /// 
		extrahead(\\ & \multicolumn{1}{c}{Full Sample} & \multicolumn{2}{c}{Has Valid Home-Based RDT} \\ \cmidrule(lr){2-2} \cmidrule(lr){3-4})	/// 
		booter(1 1 0) bootpath("$data_final/_bootstrap") bootname(infopaper_bs_cluCSCOM_) ppboot(makevar) bootrep(500)

* No Additional Controls		
docpat_doc_erac got_wanted got_wanted_HR got_wanted_HR, preprog(makevar2) /// 
	cluvar($cluvar) widc(0.15\linewidth) eracorder(1 1 2) extra($cont_strat $cont_date) /// 
		partial($cont_strat $cont_date) type(tex) texwid(1) ///
		table("$tables/got_wanted_priorhet_match_nocont.tex") footnote($footnote0_pat_bs_nocont `indexfn' $footnote1) lab(got_wanted_priorhet_match_nocont) /// 
		prehead1($prehead1) title("Effect of Extended Provider Training on Match Between Patient Prior and Prescription by Accuracy of Pre-Consultation Malaria Beliefs - No Additional Controls") ///
	    prehead2($prehead2) pvallab("P-value: ET + ET $\times$ Prior Match = 0") catlab("Prior Match Measure") /// 
		extrahead(\\ & \multicolumn{1}{c}{Full Sample} & \multicolumn{2}{c}{Has Valid Home-Based RDT} \\ \cmidrule(lr){2-2} \cmidrule(lr){3-4})	/// 
		booter(1 1 0) bootpath("$data_final/_bootstrap") bootname(infopaper_bs_cluCSCOM_) ppboot(makevar) bootrep(500)		 
		 
		 

