
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Demographic Characteristics and Randomization Verification
	
-------------------------------------------------------------------------------------------------------------------------------------*/

* VARS IN TABLE 
* 0. sample frame
global varlist0 "nobs"
* 1. patient chars
global varlist1 "thinks_malaria num_symptoms symptomsscreening_1 symptomsscreening_2 symptomsscreening_3 symptomsscreening_4 symptomsscreening_5 symptomsscreening_6 symptomsscreening_7 daysillness99 agepatient under5 genderpatient pregnancy ethnic_bambara speak_french prischoolorless RDTresult_POS pred_mal_pos" 
* 2. malaria risk
global varlist2 "in_home_survey"

* 0. sample frame
global varlist0 "nobs"
* 1. patient chars
global varlist1 "num_symptoms symptomsscreening_1 symptomsscreening_2 symptomsscreening_3 symptomsscreening_4 symptomsscreening_5 symptomsscreening_6 symptomsscreening_7 daysillness99 agepatient under5 genderpatient pregnancy RDTresult_POS pred_mal_pos"
* 2. respondent / HH chars
global varlist2 "thinks_malaria respondent gender ethnic_bambara speak_french readwrite_fluent_french prischoolorless total_hh_members_H HH_frac_14 HH_frac_job income_percap_H rent_value_H HH_frac_nets"
	
la var under5 "Under 5 Years Old"

preserve
		
local namestr  `" "\it{A. Sample Frame}" "' 
	di `"`namestr'"'
label var thinks_malaria "Respondent Suspects Illness is Malaria (Pre-Consultation)"
la var genderpatient "Male"
la var pregnancy "Pregnant (Females Only)"
la var readwrite_fluent_french "Literate (in French)"
la var gender "Male"
la var ethnic_bambara "Bambara"
la var thinks_malaria "Suspects Malaria"
la var rent_value_H "Rental Value of Home\sym{+}"
la var symptomsscreening_4 "Poor Appetite"
la var symptomsscreening_7 "Weakness/Fatigue"
la var agepatient "Age"
la var age "Age"
la var total_hh_members_H "Household Size\sym{+}"
la var pred_mal_pos "Predicted Malaria Risk"
la var in_home_survey "In Home Survey"
la var has_valid_rdt_H "Took Home-Based RDT"
la var genderpatient "Male"
la var speak_french "Speaks French"
la var prischoolorless "Primary School or Less"
la var RDTresult_POS "Positive RDT (Home Test)\sym{+}"	
la var total_hh_members_H "Household Size\sym{+}" 
la var HH_frac_14 "Share HH Under 15\sym{+}"
la var HH_frac_job "Share HH Working\sym{+}"
la var income_percap_H "HH Income Per Capita\sym{+}" 
la var rent_value_H "Rental Value Home\sym{+}" 
la var HH_frac_nets "Mosquito Nets Per Capita\sym{+}"

* Varlists
	local v0= wordcount("$varlist0")
	local v1= wordcount("$varlist1")	
	local v2= wordcount("$varlist2")

local totrow= 2*(`v0'+`v1'+`v2')+3
	matrix table_randomization=J(`totrow',7,.)
	matrix se= J(`totrow',1,.)
	
local part1 "\addlinespace\multicolumn{6}{l}{\it{A. Sample Frame (Clinic $\times$ Day-Level Observations)}}\\"
	
loc f = 2

foreach var in $varlist0 {

	local lbz: variable label `var'
		local namestr " `namestr' "`lbz'" "\thinspace" "

	local q= `f'+1
	local part`f' "\enspace `lbz' &"
	local part`q' "\thinspace &" 	

	*Regressions
	if "$cont_strat"!="" {
		xtset info_strata
		xtreg `var' patient_info infotreat $cont_date, clu($cluvar) fe 
		
	}
	if "$cont_strat"=="" {
		reg `var' patient_info infotreat $cont_date, clu($cluvar) 
	}

		local coeff_patient_info: display %19.3f _b[patient_info]
		local coeff_infotreat:  display %19.3f _b[infotreat]
		local se_patient_info: display %19.3f _se[patient_info]
		local se_infotreat:  display %19.3f _se[infotreat]
		
		matrix table_randomization[`f',2] =`coeff_patient_info'
		matrix table_randomization[`f',3] =`coeff_infotreat'

		matrix table_randomization[`f'+1,2] =`se_patient_info'
		matrix table_randomization[`f'+1,3] =`se_infotreat'

		matrix se[`f'+1,1]=1
		
		*P-value
		test patient_info==infotreat==0
		local p_value1: display %7.3f `r(p)'
		matrix table_randomization[`f',4] =`p_value1'

		*Number of observations
		matrix table_randomization[`f',5] =e(N)
		
		*Average for treatment group
		sum `var' if infotreat+patient_info==0 & e(sample)
		local control_mean: display %19.3f r(mean)
		local control_sd: display %19.3f r(sd)

		matrix table_randomization[`f',1] =`control_mean'
		matrix table_randomization[`f'+1,1] =`control_sd'
		
		*Increase the counter of the row 
		loc f = `f' + 2

}

local sustring ""
local sutest1 ""
local sutest2 ""

local part`f' "\addlinespace\multicolumn{6}{l}{\it{B. Patient Characteristics}}\\"
	
local f = `f'+1

local namestr " `namestr' "\it{B. Patient Characteristics}" "

foreach var in $varlist1 {


local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &"
	
*Regressions
reg `var'  patient_info infotreat $cont_strat $cont_date
	est store E`var'
	local sustring "`sustring' E`var'"
	local sutest2 "`sutest2' [E`var'_mean]patient_info="
	local sutest1 "`sutest1' [E`var'_mean]infotreat="
 reg `var' patient_info infotreat $cont_strat $cont_date, clu($cluvar)
	local coeff_patient_info: display %19.3f _b[patient_info]
	local coeff_infotreat:  display %19.3f _b[infotreat]
	local se_patient_info: display %19.3f _se[patient_info]
	local se_infotreat:  display %19.3f _se[infotreat]
	
	matrix table_randomization[`f',2] =`coeff_patient_info'
	matrix table_randomization[`f',3] =`coeff_infotreat'

	matrix table_randomization[`f'+1,2] =`se_patient_info'
	matrix table_randomization[`f'+1,3] =`se_infotreat'

	matrix se[`f'+1,1]=1
	
	*P-value
	test patient_info==infotreat==0
	local p_value1: display %7.3f `r(p)'
	matrix table_randomization[`f',4] =`p_value1'

	*Number of observations
	matrix table_randomization[`f',5] =e(N)
	
	*Average for treatment group
	sum `var' if infotreat+patient_info==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2

}

local part`f' "\addlinespace\multicolumn{6}{l}{\it{C. Respondent and Household Characteristics}}\\"
	
local f = `f'+1

local namestr " `namestr' "\it{C. RH Chars}" "

foreach var in $varlist2 {


local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &"
	
*Regressions
reg `var'  patient_info infotreat $cont_strat $cont_date
	est store E`var'
	local sustring "`sustring' E`var'"
	local sutest2 "`sutest2' [E`var'_mean]patient_info="
	local sutest1 "`sutest1' [E`var'_mean]infotreat="
 reg `var' patient_info infotreat $cont_strat $cont_date, clu($cluvar)
	local coeff_patient_info: display %19.3f _b[patient_info]
	local coeff_infotreat:  display %19.3f _b[infotreat]
	local se_patient_info: display %19.3f _se[patient_info]
	local se_infotreat:  display %19.3f _se[infotreat]
	
	matrix table_randomization[`f',2] =`coeff_patient_info'
	matrix table_randomization[`f',3] =`coeff_infotreat'

	matrix table_randomization[`f'+1,2] =`se_patient_info'
	matrix table_randomization[`f'+1,3] =`se_infotreat'

	matrix se[`f'+1,1]=1
	
	*P-value
	test patient_info==infotreat==0
	local p_value1: display %7.3f `r(p)'
	matrix table_randomization[`f',4] =`p_value1'

	*Number of observations
	matrix table_randomization[`f',5] =e(N)
	
	*Average for treatment group
	sum `var' if infotreat+patient_info==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2

}
		
mat li table_randomization


****************************

local sutest1 "`sutest1' 0"
local sutest2 "`sutest2' 0"
	
//	suest `sustring', clu($cluvar)
//	test `sutest1'
//	test `sutest2'
	
local df= e(df_r)
		
mat li table_randomization
matrix rownames table_randomization= `namestr'

local bc = rowsof(table_randomization)

matrix stars = J(`bc',5,0)

	local end0= `v0'*2
	local start1= `end0'+3
	local end1= `start1' + `v1'*2 - 1
	local start2= `end1'+2
	local end2= `totrow'
	di `start1' 
	di `end1'
	di `start2'
	di `end2'
	
local i=4

forvalues k = 2(2)`end0' {

	if table_randomization[`k',`i']<=.01{
	local star "1"
	}
	if table_randomization[`k',`i']>.01 & table_randomization[`k',`i']<=.05{
	local star "2"
	}
	if table_randomization[`k',`i']>.05 & table_randomization[`k',`i']<=.10{
	local star "3"
	}
	if table_randomization[`k',`i']>.10{
	local star "0"
	}
	di
    matrix stars[`k',`i'] = `star'
}

forvalues k = `start1'(2)`end1' {

	if table_randomization[`k',`i']<=.01{
	local star "1"
	}
	if table_randomization[`k',`i']>.01 & table_randomization[`k',`i']<=.05{
	local star "2"
	}
	if table_randomization[`k',`i']>.05 & table_randomization[`k',`i']<=.10{
	local star "3"
	}
	if table_randomization[`k',`i']>.10 {
	local star "0"
	}
	di
    matrix stars[`k',`i'] = `star'
}

forvalues k = `start2'(2)`end2' {

	if table_randomization[`k',`i']<=.01{
	local star "1"
	}
	if table_randomization[`k',`i']>.01 & table_randomization[`k',`i']<=.05{
	local star "2"
	}
	if table_randomization[`k',`i']>.05 & table_randomization[`k',`i']<=.10{
	local star "3"
	}
	if table_randomization[`k',`i']>.10 {
	local star "0"
	}
	di
    matrix stars[`k',`i'] = `star'
}

// use critical values from t-distribution, just as is done in regressions
local cv10= abs(invt(`df',.05))
local cv5= abs(invt(`df',.025))
local cv1= abs(invt(`df',.005))
	di `df'
	
forvalues i=2(1)3{

	forvalues k = 2(2)`end0' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'
	}

	forvalues k = `start1'(2)`end1' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'	
		
		}	

	forvalues k = `start2'(2)`end2' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'	
		
		}		
}

drop _all
svmat table_randomization
svmat stars
svmat se
g t0=""
	forval i=1/`totrow' {
		di "`part`i''"
		replace t0= "`part`i''" if _n==`i'
	}
	
forval var=1/5 {
		tostring table_randomization`var', format("%09.3g") replace force
			replace table_randomization`var'="" if table_randomization`var'=="."
			replace table_randomization`var'="0"+table_randomization`var' if substr(table_randomization`var',1,1)=="." 
		replace table_randomization`var'= table_randomization`var'+"\sym{*}" if stars`var'==3
		replace table_randomization`var'= table_randomization`var'+"\sym{**}" if stars`var'==2
		replace table_randomization`var'= table_randomization`var'+"\sym{***}" if stars`var'==1
		
	}
replace table_randomization1= "["+table_randomization1+"]" if se1==1

forval i=2/3 {
		replace table_randomization`i'="("+table_randomization`i'+")" if se1==1
	}

forval i=1/4 {
		replace table_randomization`i'= table_randomization`i'+"&" if substr(t0,1,7)!="\multic"
	}
		replace table_randomization5= table_randomization5+"\\" if table_randomization5!="" | substr(t0,1,7)=="\multic"
		replace table_randomization5= table_randomization5+"& \\" if table_randomization5==""	
		
set obs `=_N+2'		
	g index= _n
	replace index=0 if _n==_N-1
	sort index
order t0 table_randomization1-table_randomization5
keep t0-table_randomization5
	drop if t0=="" & _n!=1 & _n!=_N
list, clean 

#delimit ;

if "$cont_strat"!="" {;
local fn "\emph{Notes:} Robust standard errors clustered at the $clulevel level in parentheses. All regressions include strata and survey date fixed effects.
		 $^+$ indicates that variable was recorded in the home survey only. Variables measured in CFA and duration of illness top-coded at the 99th percentile. CFA610 $\approx$ USD1. $footnote1";
		 };
if "$cont_strat"=="" {;
local fn "\emph{Notes:} Robust standard errors clustered at the $clulevel level in parentheses. All regressions include survey date fixed effects.
		 $^+$ indicates that variable was recorded in the home survey only. Variables measured in CFA and duration of illness top-coded at the 99th percentile. CFA610 $\approx$ USD1. $footnote1";
		 };		 
		 
local text0 "\begin{table}[h!] \begin{adjustbox}{max width=1\textwidth, max totalheight=.9\textheight} \begin{threeparttable} \caption{Demographic Characteristics and Randomization Verification} \label{pat_balance} { 
			\begin{tabular}{l*{6}{c}} \toprule & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)} \\
			&  &  \multicolumn{2}{c}{Regression Coefficients} & \multicolumn{1}{c}{P-Values} &  \\ 
			\cmidrule(lr){3-4}  & 
				\multicolumn{1}{c}{\shortstack{Control\\Mean}} & \multicolumn{1}{c}{\shortstack{Patient\\Info}} & \multicolumn{1}{c}{\shortstack{Extended \\ Training}}  & 
				\multicolumn{1}{c}{\shortstack{Joint Test\\ PI=ET=0}} & \multicolumn{1}{c}{N} \\ \midrule";
local textlast "\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="`text0'" if _n==1
	replace t0="`textlast'" if _n==_N

* Output	
outfile t0-table_randomization5 using "$tables/pat_balance.tex", noquote replace wide		

restore
