
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Consultation Waiting Time and Patient Information Implementation
	
-------------------------------------------------------------------------------------------------------------------------------------*/

local namestr ""
	* 0. sample frame
	* 1. implementation
global varlist1 "timewaiting_H video_complete_PI time_watched_minutes"
	
* Time watching the video
gen minutes=substr( video_incomplete_time_PI,1,1)
gen seconds=substr( video_incomplete_time_PI,6,2)	
destring minutes, replace
destring seconds, replace
gen time_watched_minutes=minutes+seconds/60
	
preserve
		
label var video_complete_PI "Watched the Entire Video\sym{*}"
la var time_watched_minutes "Min. Watched (if Partial)\sym{*}"
la var timewaiting_H "Min. Waiting for Consultation\sym{+}"

* Varlists
	local v1= wordcount("$varlist1")	

local totrow= 2*(`v1')
	matrix table_implementation=J(`totrow',7,.)
	matrix se= J(`totrow',2,.)


loc f = 1

foreach var in $varlist1 {

local lbz: variable label `var'
	
	local namestr " `namestr' "`lbz'" "\thinspace" "

local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 	
	
	*Average for control group
	sum `var' if patient_info==0 
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_implementation[`f',1] =`control_mean'
	matrix table_implementation[`f'+1,1] =`control_sd'

	matrix se[`f'+1,1]=1
		matrix se[`f'+1,2]=1

	*Average for PI group
	sum `var' if patient_info==1 
	local PI_mean: display %19.3f r(mean)
	local PI_sd: display %19.3f r(sd)

	matrix table_implementation[`f',2] =`PI_mean'
	matrix table_implementation[`f'+1,2] =`PI_sd'

	*Number of observations
	sum `var' if patient_info!=.	
	matrix table_implementation[`f',3] =r(N)

	*Increase the counter of the row 
	loc f = `f' + 2

}


matrix rownames table_implementation= `namestr'

local bc = rowsof(table_implementation)


drop _all
svmat table_implementation
svmat se
g t0=""
	forval i=1/`totrow' {
		di "`part`i''"
		replace t0= "`part`i''" if _n==`i'
	}

forval var=1/2 {
		tostring table_implementation`var', format("%9.3f") replace force
			replace table_implementation`var'="" if table_implementation`var'=="."
			replace table_implementation`var'="0"+table_implementation`var' if substr(table_implementation`var',1,1)=="." 
		
	}
		tostring table_implementation3, format("%9.0f") replace force
			replace table_implementation3="" if table_implementation3=="."
			replace table_implementation3="0"+table_implementation3 if substr(table_implementation3,1,1)=="." 
		
replace table_implementation1= "["+table_implementation1+"]" if se1==1 & table_implementation1!=""
replace table_implementation2= "["+table_implementation2+"]" if se2==1 & table_implementation2!=""

forval i=1/2 {
		replace table_implementation`i'= table_implementation`i'+"&" if substr(t0,1,7)!="\multic"
	}
		replace table_implementation3= table_implementation3+"\\" if table_implementation3!="" | substr(t0,1,7)=="\multic"
		replace table_implementation3= table_implementation3+"& \\" if table_implementation3==""	
		
set obs `=_N+2'		
	g index= _n
	replace index=0 if _n==_N-1
	sort index
order t0 table_implementation1-table_implementation3
keep t0-table_implementation3
	drop if t0=="" & _n!=1 & _n!=_N
list, clean 

#delimit ;
local fn "\emph{Notes:} Standard deviations in brackets. $^+$ Indicates that variable was recorded in the home survey only. $^*$ Indicates that the variable comes from administrative records of intervention officers.";
local text0 "\begin{table}[h!] \begin{adjustbox}{max width=1\textwidth, max totalheight=.9\textheight} \begin{threeparttable} \caption{Consultation Waiting Time and Patient Information Implementation} \label{pat_implementation} { 
			\begin{tabular}{l*{4}{c}} \toprule & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)}  \\
			& \multicolumn{1}{c}{\shortstack{Control\\Mean}} & \multicolumn{1}{c}{\shortstack{Patient Info\\Mean}} & \multicolumn{1}{c}{N} \\ \midrule";
local textlast "\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="`text0'" if _n==1
	replace t0="`textlast'" if _n==_N

* Output	
outfile t0-table_implementation3 using "$tables/pat_implementation.tex", noquote replace wide		

restore
