
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Randomization Verification 
	
-------------------------------------------------------------------------------------------------------------------------------------*/

global cluvar2 "$cluvar"

global varlist_dr0 "trueorfalse_1 meds_correct_simple_mal_1 low_parasite_test_90more_1 high_parasite_test_90_more_1 symp_correct_severe_mal_1 interval_15_2030_1 correct_knowledge"
global varlist_cs "avg_pat can_do_ge frac_test_rdt frac_test_ge frac_pos_tested"

* Varlists
	local v0= wordcount("$varlist_dr0")
	local vc= wordcount("$varlist_cs")
	local v1= 3 
	local totrow= 2*(`v0'+`vc'+`v1')+3
	matrix table_randomization=J(`totrow',4,.)
	matrix se= J(`totrow',1,.)

********************************************************************************
* PANEL A: CLINIC CHARACTERISTICS
********************************************************************************
use "$data_final/LSS_info_CSComCensus_clean", clear
	
local namestr  `" "\addlinespace\it{A. Provider-Reported Clinic Characteristics}" "' 
	di `"`namestr'"'	

local part1 "\addlinespace\it{A. Provider-Reported Clinic Characteristics} &"
loc f = 2	
	
foreach var in $varlist_cs {

	local lbz: variable label `var'
		local namestr " `namestr' "`lbz'" "\thinspace" "

	local q= `f'+1
	local part`f' "\enspace `lbz' &"
	local part`q' "\thinspace &" 	

	*Regressions
		reg `var' infotreat, clu($cluvar2) 

		local coeff_infotreat: display %19.3f _b[infotreat]
		local se_infotreat: display %19.3f _se[infotreat]
		
		matrix table_randomization[`f',2] =`coeff_infotreat'
		matrix table_randomization[`f'+1,2] =`se_infotreat'

		matrix se[`f'+1,1]=1

		*Number of observations
		matrix table_randomization[`f',3] =e(N)
		
		*Average for treatment group
		sum `var' if infotreat==0 & e(sample)
		local control_mean: display %19.3f r(mean)
		local control_sd: display %19.3f r(sd)

		matrix table_randomization[`f',1] =`control_mean'
		matrix table_randomization[`f'+1,1] =`control_sd'
		
		*Increase the counter of the row 
		loc f = `f' + 2

}

********************************************************************************
* PANEL B: DOCTOR ATTENDANCE
********************************************************************************

* CHECK BALANCE ON ATTENDANCE -- OFFICIAL ROSTER

use "$data_final/LSS_info_CSComs_Agent_Training_corrected", clear

local lbz: variable label nobs
	local namestr " `namestr' "`lbz'" "\thinspace" "

local part`f' "\addlinespace \it{B. Provider Attendance} &"
local f = `f'+1

local namestr " `namestr' "\it{B. Provider Attendance}" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 

	reg nobs infotreat $cont_strat, clu($cluvar2) 
	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]

	matrix table_randomization[`f',2] =`coeff_infotreat'
	matrix table_randomization[`f'+1,2] =`se_infotreat'

	matrix se[`f'+1,1]=1
	
	*Number of observations
	matrix table_randomization[`f',3] =e(N)
	
	*Average for treatment group
	sum nobs if infotreat==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2
	
* CHECK BALANCE ON ATTENDANCE -- PRE TETS SUBMITTED

use "$data_final/LSS_info_PreTest_Doctors_individual_level_allcont.dta", clear
	
gen freq=1
	egen nobs= sum(freq), by(cscomnum_OS)
	bysort cscomnum_OS: replace nobs=. if _n!=1
	la var nobs "Pre-Tests Submitted per Clinic"
	drop freq
	drop if nobs==.
	
local lbz: variable label nobs
	local namestr " `namestr' "`lbz'" "\thinspace" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 
	merge 1:1 cscomnum_OS using "$data_final/LSS_info_CSComCensus_clean" 
		replace nobs=0 if _merge!=3 

	reg nobs infotreat $cont_strat, clu($cluvar2)

	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]
	
	matrix table_randomization[`f',2] =`coeff_infotreat'
	matrix table_randomization[`f'+1,2] =`se_infotreat'

	matrix se[`f'+1,1]=1

	*Number of observations
	matrix table_randomization[`f',3] =e(N)
	
	*Average for treatment group
	sum nobs if infotreat==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2	

* CHECK BALANCE ON ATTENDANCE -- POST TESTS SUBMITTED
	
use "$data_final/LSS_info_PostTest_Doctors_individual_level_allcont.dta", clear

gen freq=1
	egen nobs= sum(freq), by(cscomnum_OS)
	bysort cscomnum_OS: replace nobs=. if _n!=1
	la var nobs "Post tests submitted per clinic"
	drop freq
	drop if nobs==.
	
local lbz: variable label nobs
	local namestr " `namestr' "`lbz'" "\thinspace" "
	
local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 

	reg nobs infotreat $cont_strat, clu($cluvar2)

	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]
	
	matrix table_randomization[`f',2] =`coeff_infotreat'
	matrix table_randomization[`f'+1,2] =`se_infotreat'

	matrix se[`f'+1,1]=1

	*Number of observations
	matrix table_randomization[`f',3] =e(N)
	
	*Average for treatment group
	sum nobs if infotreat==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2

* ******************************************************************************
* PANEL C: CHECK BALANCE ON DOCTOR PRE-TESTS
* ******************************************************************************

use "$data_final/LSS_info_PreTest_Doctors_individual_level_allcont.dta", clear

local part`f' "\addlinespace\it{C. Provider Pre-Test Knowledge} &"
local f = `f'+1

local namestr " `namestr' "\it{C. Provider Pre-Test Knowledge}" "
	
foreach var in $varlist_dr0 {

local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "

local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 	

*Regressions
	reg `var' infotreat $cont_strat, clu($cluvar2)

	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]
	
	matrix table_randomization[`f',2] =`coeff_infotreat'
	matrix table_randomization[`f'+1,2] =`se_infotreat'

	matrix se[`f'+1,1]=1
	
	*Number of observations
	matrix table_randomization[`f',3] =e(N)
	
	*Average for treatment group
	sum `var' if infotreat==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[`f',1] =`control_mean'
	matrix table_randomization[`f'+1,1] =`control_sd'
	
	*Increase the counter of the row 
	loc f = `f' + 2

}

local df= e(df_r)
	
mat li table_randomization

local bc = rowsof(table_randomization)

matrix stars = J(`bc',4,0)

local end0=`vc'*2
local start1=`end0'+3
local end1=`start1'+2
local start2= `end1'+3
local end2= `bc'
	di `end0'
	di `start1'
	di `start2'
	di `end2'

// use critical values from t-distribution, just as is done in regressions
local cv10= abs(invt(`df',.05))
local cv5= abs(invt(`df',.025))
local cv1= abs(invt(`df',.005))


local i=2

	forvalues k = 2(2)`end0' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'
	}

	forvalues k = `start1'(2)`end1' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'	
		
		}	
	forvalues k = `start2'(2)`end2' {

		local ttest=abs(table_randomization[`k',`i']/table_randomization[`k'+1,`i'])
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`k',`i'] = `star'	
		
		}	

drop _all
svmat table_randomization
svmat stars
svmat se
g t0=""
	forval i=1/`totrow' {
		di "`part`i''"
		replace t0= "`part`i''" if _n==`i'
	}
	
forval var=1/2 {
		tostring table_randomization`var', format("%9.3f") replace force
			replace table_randomization`var'="" if table_randomization`var'=="."
			replace table_randomization`var'="0"+table_randomization`var' if substr(table_randomization`var',1,1)=="." 
		replace table_randomization`var'= table_randomization`var'+"\sym{*}" if stars`var'==3
		replace table_randomization`var'= table_randomization`var'+"\sym{**}" if stars`var'==2
		replace table_randomization`var'= table_randomization`var'+"\sym{***}" if stars`var'==1
		
	}
replace table_randomization1= "["+table_randomization1+"]" if se1==1
replace table_randomization2="("+table_randomization2+")" if se1==1


forval i=1/2 {
		replace table_randomization`i'= table_randomization`i'+"&"
	}
		tostring table_randomization3, format("%9.0f") replace force
		replace table_randomization3="" if table_randomization3=="."
		replace table_randomization3="0"+table_randomization3 if substr(table_randomization3,1,1)=="." 
	
		replace table_randomization3= table_randomization3+"\\" if table_randomization3!=""
		replace table_randomization3= table_randomization3+"& \\" if table_randomization3==""	
		
set obs `=_N+2'		
	g index= _n
	replace index=0 if _n==_N-1
	sort index
order t0 table_randomization1-table_randomization3
keep t0-table_randomization3
list, clean 

#delimit ;
local fn "$footnote0_doc_nocont $footnote1";
local text0 "\begin{table}[h!] \begin{adjustbox}{max width=.85\textwidth} \begin{threeparttable} \caption{Randomization Verification: Clinic Census and Health Worker Pre-Training Survey} \label{doc_balance_pre_training} { 
			\begin{tabular}{l*{7}{c}} \toprule & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)}   \\
            & \multicolumn{1}{c}{\shortstack{Basic \\ Training \\Mean}} & \multicolumn{1}{c}{\shortstack{Extended\\Provider\\Training}}  &  \multicolumn{1}{c}{N} \\ \midrule";
local textlast "\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="`text0'" if _n==1
	replace t0="`textlast'" if _n==_N

* Output
outfile t0-table_randomization3 using "$tables/doc_balance_pre_training.tex", noquote replace wide		


