
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Effect of Extended Provider Training on Patient Satisfaction by Accuracy of Pre-Consultation Malaria Beliefs
	
-------------------------------------------------------------------------------------------------------------------------------------*/

cap prog drop makevar
  prog define makevar
	
g erac=prior_match_pred*infotreat
g risk=prior_match_pred
	la var risk "Match: Malaria Prior and Malaria Risk"
	la var erac "Extended Training $\times$ Prior-Risk Match"
	la var infotreat "Extended Training"
			
g prior_match=(thinks_malaria*RDTresult_POS + (1-thinks_malaria)*RDTresult_NEG)
	g prior_match_info= infotreat*prior_match
	g prior_match_info_pred= infotreat*prior_match_pred
	
g mal_test_info= reported_Malaria_test*infotreat
	la var prior_match "Malaria Prior Does Match Home RDT"
	la var prior_match_pred "Expected Match - Malaria Status and Prior"
	la var reported_Malaria_test "Malaria Test at Clinic"
	la var prior_match_info "Extended Training $\times$ Malaria Prior Matches"
	la var prior_match_info_pred "Extended Training $\times$ Expected Malaria Prior Match"
	la var mal_test_info "Extended Training $\times$ Malaria Test at Clinic"

g risk1= prior_match_pred 
g risk2= prior_match 
	la var risk1 "Expected Prior Match"
	la var risk2 "Actual Prior Match (Home RDT)"
g erac1= risk1*infotreat
g erac2= risk2*infotreat

g infotreatXPI= infotreat*patient_info
la var patient_info "Patient Information"

la var Asat_index_H "Overall Satisfaction Index"
	local mylab: var label Asat_index_H
	g Asat_index_HR= Asat_index_H if !missing(RDTresult_NEG)
		la var Asat_index_HR "`mylab'"
		
end


makevar

cap prog drop makevar2
	prog define makevar2
		args myct
		  replace erac= erac`myct'
		  replace risk= risk`myct'
	end
	

#delimit ;
local indexfn "Index components are standardized relative to the basic provider training $\times$ no patient information mean. 
			   In cases where some (but not all) index components for a respondent are missing, missing components are imputed 
			   to the treatment group mean prior to standardization.";
#delimit cr

* ------------------------------------------------------------------------------
* SATISFACTION INDICES
* ------------------------------------------------------------------------------
/*
cap prog drop indexmake
prog define indexmake 

ren doctorsfinancialsituation_H dfinsit_H
ren doctorsmeddontneed_H dmednot_H

local posframe "explaintests_H treatbasedresults_H explaindiagnosis_H doctorspatients_H doctorscosts_H doctorslisten_H"			   
local negframe "addmedicaltesting_H fewermedicaltests_H diffaddmed_H fewermed_H dfinsit_H dmednot_H"			   
	
foreach var in `posframe' `negframe'  {
	replace `var'=. if `var'<-2
	g A`var'= `var'>0 if !missing(`var')
	g NA`var'= -1*A`var'
	
		local mylab: var label `var'
			if "`mylab'"=="" local mylab "`var'"
		la var A`var' "Agrees: `mylab'"
		la var NA`var' "Negative of Agree: `mylab'"
}

	egen grouper= group(infotreat patient_info)
	g info_control= (infotreat==0 & patient_info==0)
	
local sat_index_H "explaindiagnosis_H explaintests_H treatbasedresults_H addmedicaltesting_H fewermedicaltests_H diffaddmed_H fewermed_H"  // main index
local sat_index_tests_H "explaintests_H treatbasedresults_H  addmedicaltesting_H fewermedicaltests_H "                                          // testing 
local sat_index_meds_H "diffaddmed_H fewermed_H" // meds

foreach stem in sat_index_H sat_index_tests_H sat_index_meds_H {

	local A`stem'= ""
	
	foreach var in ``stem'' {
		di "`var'"
		if strpos("`posframe'","`var'")>0 { 
			local A`stem'= "`A`stem'' A`var'"
		}
		if strpos("`negframe'","`var'")>0 {
			local A`stem'= "`A`stem'' NA`var'"
		}
	}
	makeindex `A`stem'', indexname(A`stem') groupby(grouper) omit(info_control)

}

la var Asat_index_H "Satisfaction: Overall Index (Agree Dummies Only)"
la var Asat_index_tests_H "Satisfaction: Tests (Agree Dummies Only)"
la var Asat_index_meds_H "Satisfaction: Medications (Agree Dummies Only)"

ren dfinsit_H doctorsfinancialsituation_H
ren dmednot_H doctorsmeddontneed_H

drop grouper info_control

end
	 
indexmake
*/	

la var Asat_index_tests_H "Testing Sub-Index" 
la var Asat_index_meds_H "Medications Sub-Index"
la var Asat_index_H "Overall Satisfaction Index"

* W/ controls
* CL: In the program "risk" is included in the hd set of controls, and patient_info as a treatment, along with the interactions
docpat_doc_erac Asat_index_H Asat_index_HR Asat_index_HR, preprog(makevar2) /// 
	cluvar($cluvar) widc(0.15\linewidth) eracorder(1 1 2) extra($cont_strat $cont_lso $cont_date) partial($cont_strat $cont_date) type(tex) texwid(1) ///
		table("$tables/doc_patient_satisfaction_priorhet_match.tex") footnote($footnote0_alt_pat_bs $footnote1) lab(doc_patient_satisfaction_priorhet_match) /// 
		prehead1($prehead1) title("Effect of Extended Provider Training on Patient Satisfaction by Accuracy of Pre-Consultation Malaria Beliefs") ///
	    prehead2($prehead2) pvallab("P-value: ET + ET $\times$ Prior Match = 0") catlab("Prior Match Measure") /// 
		extrahead(\\ & \multicolumn{1}{c}{Full Sample} & \multicolumn{2}{c}{Has Valid Home-Based RDT} \\ \cmidrule(lr){2-2} \cmidrule(lr){3-4})	/// 
		booter(1 1 0) bootpath("$data_final/_bootstrap") bootname(infopaper_bs_cluCSCOM_) ppboot(makevar) bootrep(500)
		
* No Additional Controls		
docpat_doc_erac Asat_index_H Asat_index_HR Asat_index_HR, preprog(makevar2) /// 
	cluvar($cluvar) widc(0.15\linewidth) eracorder(1 1 2) extra($cont_strat $cont_date) partial($cont_strat $cont_date) type(tex) texwid(1) ///
		table("$tables/doc_patient_satisfaction_priorhet_match_nocont.tex") footnote($footnote0_pat_bs_nocont $footnote1) lab(doc_patient_satisfaction_priorhet_match_nocont) /// 
		prehead1($prehead1) title("Effect of Extended Provider Training on Patient Satisfaction by Accuracy of Pre-Consultation Malaria Beliefs - No Additional Controls") ///
	    prehead2($prehead2) pvallab("P-value: ET + ET $\times$ Prior Match = 0") catlab("Prior Match Measure") /// 
		extrahead(\\ & \multicolumn{1}{c}{Full Sample} & \multicolumn{2}{c}{Has Valid Home-Based RDT} \\ \cmidrule(lr){2-2} \cmidrule(lr){3-4})	/// 
		booter(1 1 0) bootpath("$data_final/_bootstrap") bootname(infopaper_bs_cluCSCOM_) ppboot(makevar) bootrep(500)		 

