
/*-------------------------------------------------------------------------------------------------------------------------------------
	
	Table: Effect of Extended Provider Training on Learning
	
-------------------------------------------------------------------------------------------------------------------------------------*/

local varlist "rdt_beliefs_index simplemalaria_rdtpos severemalaria_rdtpos notmalaria_rdtneg ge_beliefs_index simplemalaria_gepos severemalaria_gepos notmalaria_geneg"
* Varlists
	local v= wordcount("`varlist'")
local totrow= 15
	matrix table_randomization=J(`totrow',8,.)
	matrix se= J(`totrow',1,.)
	
********************************************************************************
* CLINIC CHARACTERISTICS
********************************************************************************
use "$data_final/LSS_info_PostTest_Doctors_individual_level_allcont.dta", clear

cap prog drop makevar
	prog define makevar

gen simplemalaria_rdtpos_aux	=simplemalaria_rdtpos
gen simplemalaria_gepos_aux		=simplemalaria_gepos
gen severemalaria_rdtpos_aux	=severemalaria_rdtpos
gen severemalaria_gepos_aux		=severemalaria_gepos
gen notmalaria_rdtneg_aux		=notmalaria_rdtneg
gen notmalaria_geneg_aux		=notmalaria_geneg

* Standardization
g ok_rdt=0
g ok_ge=0

foreach var in simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux {
	replace ok_rdt=ok_rdt+1 if !missing(`var')
}

foreach var in simplemalaria_gepos_aux  severemalaria_gepos_aux notmalaria_geneg_aux {
	replace ok_ge=ok_ge+1 if !missing(`var')
}
	
foreach var in simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux {
	local labelq : variable label `var'
	g X`var'= `var' 
	sum X`var' if infotreat==1
		replace X`var'=r(mean) if infotreat==1 & missing(X`var') & ok_rdt>0		
	sum X`var' if infotreat==0
		replace X`var'=r(mean) if infotreat==0 & missing(X`var') & ok_rdt>0

	sum X`var' if infotreat==0 
		local mean_`var'=r(mean)	
		local sd_`var'=r(sd)
	gen std_`var'=(X`var'-`mean_`var'')/`sd_`var'' 
	lab var std_`var' "Standarized `labelq'"
}

foreach var in simplemalaria_gepos_aux  severemalaria_gepos_aux notmalaria_geneg_aux  {
	local labelq : variable label `var'
	g X`var'= `var' 
	sum X`var' if infotreat==1
		replace X`var'=r(mean) if infotreat==1 & missing(X`var') & ok_ge>0		
	sum X`var' if infotreat==0
		replace X`var'=r(mean) if infotreat==0 & missing(X`var') & ok_ge>0

	sum X`var' if infotreat==0 
		local mean_`var'=r(mean)	
		local sd_`var'=r(sd)
	gen std_`var'=(X`var'-`mean_`var'')/`sd_`var'' 
	lab var std_`var' "Standarized `labelq'"
}

* swindex
g control= 1-infotreat
swindex simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux , ge(rb2) normby(control)
swindex simplemalaria_gepos_aux   severemalaria_gepos_aux  notmalaria_geneg_aux  , ge(mb2) normby(control)

* Mean of std variables
gen rdt_beliefs_index=(std_simplemalaria_rdtpos_aux + std_severemalaria_rdtpos_aux + std_notmalaria_rdtneg_aux)/3
	label var rdt_beliefs_index "RDT Beliefs Index"
gen ge_beliefs_index=(std_simplemalaria_gepos_aux + std_severemalaria_gepos_aux + std_notmalaria_geneg_aux)/3
	label var ge_beliefs_index "GE/GS Beliefs Index"
drop *_aux
	
la define infotreat 0 "Basic Training" 1 "Extended RDT Training"
la val infotreat infotreat	
la var simplemalaria_rdtpos "Share RDT Positive (Simple Malaria)" 
replace simplemalaria_rdtpos=simplemalaria_rdtpos/100
la var severemalaria_rdtpos "Share RDT Positive (Severe Malaria)" 
replace severemalaria_rdtpos=severemalaria_rdtpos/100
la var notmalaria_rdtneg "Share RDT Negative (No Malaria)" 
replace notmalaria_rdtneg=notmalaria_rdtneg/100
la var simplemalaria_gepos "Share GE/FM Positive (Simple Malaria)"
replace simplemalaria_gepos=simplemalaria_gepos/100
la var severemalaria_gepos "Share GE/FM Positive (Severe Malaria)" 
replace severemalaria_gepos=severemalaria_gepos/100
la var notmalaria_geneg "Share GE/FM Negative (No Malaria)" 
replace notmalaria_geneg=notmalaria_geneg/100
la var meds_correct_simple_mal_2 "Correct Meds for Simple Malaria Treatment"
la var  symp_correct_severe_mal_2 "Correct Symptoms Severe Malaria"
la var interval_15_2030_2 "Correct Time Interval to Read RDT"	

end

makevar

local namestr  `" "\addlinespace\it{A. Post-Training survey}" "' 
	di `"`namestr'"'	

local part2 "\addlinespace\multicolumn{3}{l}{\it{A. Post-Training survey}} \\"

loc c = 1	
	
foreach var in `varlist' {

local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "

local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 		

*Regressions
	pdslasso `var' infotreat (CC*), clu($cluvar) loptions(seed(1234))

	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]
	
	matrix table_randomization[2,`c'] =`coeff_infotreat'
	matrix table_randomization[3,`c'] =`se_infotreat'

	matrix se[3,1]=1

	*Number of observations
	matrix table_randomization[7,`c'] =e(N)
	
	*Average for treatment group
	sum `var' if infotreat==0 & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[6,`c'] =`control_mean'
	
	*Increase the counter of the row 
	loc c = `c' + 1

}

use "$data_final/LSS_info_DoctorEndlineInterview_allcont.dta", clear

cap prog drop makevar
	prog define makevar

keep if trained==1
la var simplemalaria_rdtpos "Share RDT Positive (Simple Malaria)"
la var simplemalaria_gepos "Share GE/FM Positive (Simple Malaria)"
la var severemalaria_rdtpos "Share RDT Positive (Severe Malaria)"
la var severemalaria_gepos "Share GE/FM Positive (Severe Malaria)"
la var notmalaria_rdtneg "Share RDT Negative (No Malaria)"
la var notmalaria_geneg "Share GE/FM Negative (No Malaria)"

gen simplemalaria_rdtpos_aux=simplemalaria_rdtpos
gen simplemalaria_gepos_aux=simplemalaria_gepos
gen severemalaria_rdtpos_aux=severemalaria_rdtpos
gen severemalaria_gepos_aux=severemalaria_gepos
gen notmalaria_rdtneg_aux=notmalaria_rdtneg
gen notmalaria_geneg_aux=notmalaria_geneg

* Standardization	
g ok_rdt=0
g ok_ge=0

foreach var in simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux {
	replace ok_rdt=ok_rdt+1 if !missing(`var')
}

foreach var in simplemalaria_gepos_aux  severemalaria_gepos_aux notmalaria_geneg_aux {
    replace ok_ge=ok_ge+1 if !missing(`var')
}
	
foreach var in simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux {
	local labelq : variable label `var'
	g X`var'= `var' 
	sum X`var' if infotreat==1
		replace X`var'=r(mean) if infotreat==1 & missing(X`var') & ok_rdt>0		
	sum X`var' if infotreat==0
		replace X`var'=r(mean) if infotreat==0 & missing(X`var') & ok_rdt>0

	sum X`var' if infotreat==0 
		local mean_`var'=r(mean)	
		local sd_`var'=r(sd)
	gen std_`var'=(X`var'-`mean_`var'')/`sd_`var'' 
	lab var std_`var' "Standarized `labelq'"
}

foreach var in simplemalaria_gepos_aux  severemalaria_gepos_aux notmalaria_geneg_aux  {
	local labelq : variable label `var'
	g X`var'= `var' 
	sum X`var' if infotreat==1
		replace X`var'=r(mean) if infotreat==1 & missing(X`var') & ok_ge>0		
	sum X`var' if infotreat==0
		replace X`var'=r(mean) if infotreat==0 & missing(X`var') & ok_ge>0

	sum X`var' if infotreat==0 
		local mean_`var'=r(mean)	
		local sd_`var'=r(sd)
	gen std_`var'=(X`var'-`mean_`var'')/`sd_`var'' 
	lab var std_`var' "Standarized `labelq'"
}

*swindex 
g control= 1-infotreat
swindex simplemalaria_rdtpos_aux  severemalaria_rdtpos_aux notmalaria_rdtneg_aux , ge(rb2) normby(control)
swindex simplemalaria_gepos_aux   severemalaria_gepos_aux  notmalaria_geneg_aux  , ge(mb2) normby(control)

gen rdt_beliefs_index=(std_simplemalaria_rdtpos_aux + std_severemalaria_rdtpos_aux + std_notmalaria_rdtneg_aux)/3
	label var rdt_beliefs_index "RDT Beliefs Index"
gen ge_beliefs_index=(std_simplemalaria_gepos_aux + std_severemalaria_gepos_aux + std_notmalaria_geneg_aux)/3
	label var ge_beliefs_index "GE/GS Beliefs Index"
drop *_aux

	la define infotreat 0 "Basic Training" 1 "Extended RDT Training"
	la val infotreat infotreat
la var pressuremed "Reports Pressure to Prescribe Unnecessary Medications"
la var pressuret "Reports Pressure to Administer Unnecessary Tests"

end

makevar

local c=1

local part9 "\addlinespace\multicolumn{3}{l}{\it{B. Data from Clinic Survey}} \\"

foreach var in `varlist' {

local lbz: variable label `var'
	local namestr " `namestr' "`lbz'" "\thinspace" "

local q= `f'+1
local part`f' "\enspace `lbz' &"
local part`q' "\thinspace &" 	

*Regressions
	pdslasso `var' infotreat (CC*) if trained==1, clu($cluvar) loptions(seed(1234))
									
	local coeff_infotreat: display %19.3f _b[infotreat]
	local se_infotreat: display %19.3f _se[infotreat]
	
	matrix table_randomization[10,`c'] =`coeff_infotreat'
	matrix table_randomization[11,`c'] =`se_infotreat'

	matrix se[11,1]=1
	
	*Number of observations
	matrix table_randomization[14,`c'] =e(N)
	
	*Average for treatment group
	sum `var' if infotreat==0  & e(sample)
	local control_mean: display %19.3f r(mean)
	local control_sd: display %19.3f r(sd)

	matrix table_randomization[13,`c'] =`control_mean'
	
	*Increase the counter of the row 
	loc c = `c' + 1

}

local df= e(df_r)
	
mat li table_randomization

local bc = rowsof(table_randomization)

matrix stars = J(`bc',8,0)

// use critical values from t-distribution, just as is done in regressions
local cv10= abs(invnormal(.05))
local cv5= abs(invnormal(.025))
local cv1= abs(invnormal(.005))
	
forvalues c=1(1)8{

	foreach f of numlist 2 10 {

		local ttest=abs(table_randomization[`f',`c']/table_randomization[`f'+1,`c'])
		di `ttest'
		if `ttest'<`cv10' {
		local star "0"
		}
		if `ttest'>=`cv10' & `ttest'<`cv5' {
		local star "3"
		}
		if `ttest'>=`cv5' & `ttest'<`cv1' {
		local star "2"
		}
		if `ttest'>=`cv1' & `ttest'!=. {
		local star "1"
		}
		di
		matrix stars[`f',`c'] = `star'
	}

}

drop _all
svmat table_randomization
svmat stars
svmat se

g t0=""
forval i=1/`totrow' {
	di "`part`i''"
	replace t0= "`part`i''" if _n==`i'
}
	
forval var=1/8 {
	tostring table_randomization`var', format("%9.3f") replace force
	replace table_randomization`var'="" if table_randomization`var'=="."
	replace table_randomization`var'="0"+table_randomization`var' if substr(table_randomization`var',1,1)=="." 

	replace table_randomization`var'= "("+table_randomization`var'+")" if se1==1
	replace table_randomization`var'= "["+table_randomization`var'+"]" if se1==2
	
	replace table_randomization`var'= table_randomization`var'+"\sym{*}" if stars`var'==3 
	replace table_randomization`var'= table_randomization`var'+"\sym{**}" if stars`var'==2
	replace table_randomization`var'= table_randomization`var'+"\sym{***}" if stars`var'==1
	
	replace table_randomization`var'=substr(table_randomization`var',1,2) if substr(table_randomization`var',3,6)==".000"
	replace table_randomization`var'=substr(table_randomization`var',1,3) if substr(table_randomization`var',4,7)==".000" 
		
}

forval i=1/7 {
	replace table_randomization`i'= table_randomization`i'+"&"
}
	
	replace table_randomization8= table_randomization8+"\\" if table_randomization8!=""
	replace table_randomization8= table_randomization8+"& \\" if table_randomization8==""	
		
set obs `=_N+2'		
	g index= _n
	replace index=0 if _n==_N-1
	sort index
	replace t0="\addlinespace\multicolumn{3}{l}{\it{A. Data from Post-Training Survey}} \\" if _n==2
	replace t0="\enspace Extended Training &" if _n==3
	replace t0=" &" if _n==4
	replace t0=" &" if _n==5
	replace t0=" &" if _n==6
	replace t0="\enspace Mean (Basic Training) &" if _n==7
	replace t0="\enspace N &" if _n==8
	replace t0="\addlinespace\multicolumn{3}{l}{\it{B. Data from Provider Follow-Up Survey}} \\" if _n==10
	replace t0=" &" if   _n==9
	replace t0="\enspace Extended Training &" if _n==11
	replace t0=" &" if _n==12
	replace t0=" &" if _n==13	
	replace t0="\enspace Mean (Basic Training) &" if _n==14
	replace t0="\enspace N &" if _n==15
	drop if _n==6
order t0 table_randomization1-table_randomization8

forval i=1/8 {
	replace table_randomization`i'="" if _n==2 | _n==9 // no need for &s after panel headers
}

keep t0-table_randomization8
list, clean 
		
#delimit ;

local indexfn "Index components are standardized relative to the basic provider training mean. 
			   In cases where some (but not all) index components for a respondent are missing, missing components are imputed 
			   to the treatment group mean prior to standardization.";

local fn "$footnote0_alt_doc Sample in both panels limited to providers who attended the training. `indexfn' $footnote1";
local text0 "\begin{table}[h!] \begin{adjustbox}{max width=1.5\textwidth} \begin{threeparttable} \caption{Effect of Extended Provider Training on Learning: Provider Post-Training and Clinic Endline Surveys} \label{doc_post_training_trained} { 
			\begin{tabular}{l*{9}{c}} \toprule & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)}  & \multicolumn{1}{c}{(6)}  & \multicolumn{1}{c}{(7)}  & \multicolumn{1}{c}{(8)}  \\  &  \multicolumn{4}{c}{Beliefs About RDTs} & \multicolumn{4}{c}{Beliefs About Microscopy Tests}   \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} &
		 \multicolumn{1}{c}{\shortstack{RDT \\Beliefs\\ Index}} & \multicolumn{1}{c}{\shortstack{Share RDT \\ Positive \\ Simple \\Malaria}} & \multicolumn{1}{c}{\shortstack{Share RDT \\Positive \\ Severe \\Malaria}}  & \multicolumn{1}{c}{\shortstack{Share RDT \\ Negative \\ No Malaria}}  & 
				\multicolumn{1}{c}{\shortstack{Microscopy \\Beliefs\\ Index}} & \multicolumn{1}{c}{\shortstack{Share \\ Microscopy \\ Positive: \\ Simple \\Malaria}} & \multicolumn{1}{c}{\shortstack{Share \\ Microscopy \\Positive: \\ Severe \\Malaria}}  & \multicolumn{1}{c}{\shortstack{Share \\ Microscopy \\ Negative: \\ No Malaria}}  \\ \midrule";
local textlast "\bottomrule \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
	
#delimit cr	
	replace t0="`text0'" if _n==1
	replace t0="`textlast'" if _n==_N
	drop if _n==15
list t0-table_randomization8

* Output
outfile t0-table_randomization8 using "$tables/doc_post_training_trained.tex", noquote replace wide		


